#!/bin/sh
###############################################################################
# Licensed Materials - Property of IBM
# Restricted Materials of IBM
# <PID>
# (C) Copyright IBM Corp. 2015
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp
###############################################################################

usage(){
cat <<EOF
usage: ./install_APAR_PO05086.sh <IOCTP_PASSWD> <STREAMS_HOST> <STREAMS_ROOT> <STREAMS_RTPW> <STREAMS_ADMIN>

<IOCTP_PASSWD>-The topology password of IBM Intelligent Operation Center
<STREAMS_HOST>-The host name of Streams server
<STREAMS_ROOT>-The name of Streams root user
<STREAMS_RTPW>-The password of Streams root user
<STREAMS_ADMIN>-The name of Streams administration user
EOF
}

# Check the user input parameters
if [ $# -ne 5 ]
then
	usage
	exit 1
fi

vap_top=vap_std_APAR_PO05086

pass=$1
STREAMS_HOST=`ping $2 -c 1 | sed -n '2p' | cut -d' ' -f4`
STREAMS_ACCOUNT=$3
STREAMS_PASSWORD=$4
STREAMS_ADMIN=$5

# Create user input response file
properties(){
cat <<EOF
STREAMS_HOST=$STREAMS_HOST
STREAMS_ACCOUNT=$STREAMS_ACCOUNT
STREAMS_PASSWORD=$STREAMS_PASSWORD
STREAMS_ADMIN=$STREAMS_ADMIN
EOF
}

properties > streams.properties
JAVA_WHICH=`which java`
JAVA_HOME=$(echo ${JAVA_WHICH%/*/*})

if [ -z "$1" ]
then
    echo "Password cannot be an empty string. Please enter a valid password."
   	exit 1
fi

# Update database
vap_topology=`locate vap_std.xml | grep "tools/svc/topology"`
TOPOLOGY=$(echo ${vap_topology%/*})
SVC=$(echo ${vap_topology%/*/*})
echo "SVC = $SVC"

echo "###############################################################################"
echo "# Start the install of vap_APAR_PO05086 for the VAP product."
echo "###############################################################################" 

echo "Get/create topologies on IOC."
sh getTopologies.sh $SVC $pass

echo "Import Solution iit_vap_sif_APAR_PO05086.zip"
sh $SVC/bin/ba.sh importSolution -f iit_vap_sif_APAR_PO05086.zip -r streams.properties -p $pass
 
echo "Install Topology $vap_top"
sh $SVC/bin/ba.sh installTopology -t $vap_top -r streams.properties -p $pass
if [ $? -ne 0 ]
then 
    echo "Install topology $vap_top failed"
	exit 1
fi

echo "Install topology $vap_top succeeded"
       
rm -rf streams.properties
exit 0
